@@ -2,7 +2,7 @@
 library(covid19br)
 library(dplyr)
 
-# Downloading Brazilian COVID-19 data:
+
 brazil <- downloadCovid19("brazil")
 regions <- downloadCovid19("regions")
 states <- downloadCovid19("states")
@@ -13,17 +13,20 @@ world <- downloadCovid19("world")
 
 
 
-# adding the geometry/epidemiological rates to the downloaded data:
+# adding the geometry/epidemiological rates to the data:
+regions <- readRDS("regions.rds")
 regions_geo <- regions %>%
   filter(date == max(date)) %>%
   add_geo() %>%
   add_epi_rates()
 
+states <- readRDS("states.rds")
 states_geo <- states %>%
   filter(date == max(date)) %>%
   add_geo() %>%
   add_epi_rates()
 
+cities <- readRDS("cities.rds")
 cities_geo <- cities %>%
   filter(date == max(date)) %>%
   add_geo() %>%
